@@ -1,9 +1,15 @@
 package Games::Roguelike::Utils::Pov_C;
 
-use Exporter qw(import);
-our @EXPORT = qw(checkpov_c distance findclose_c);
+# broken undil perl 5.8
+# use Exporter qw(import);
 
-our $VERSION = '0.4.' . [qw$Revision: 233 $]->[1];
+BEGIN {
+        require Exporter;
+        *{import} = \&Exporter::import;
+	our @EXPORT = qw(checkpov_c distance findclose_c);
+}
+
+our $VERSION = '0.4.' . [qw$Revision: 236 $]->[1];
 
 use Inline C => <<'END_C';
 
